
==============================================================
Sawx -- Simple Application-framework for wxPython
==============================================================



Abstract
========

This is a simple application framework system for wxPython, providing a multi-
tabbed, multi-frame environment with simple-to-understand support for dynamic
menubars, toolbars, and popup menus. Also includes many small utilities and
convenience classes, such as a tile layout control that can replace more complicated controls like the wx.aui.AuiManager.


Images
======

Professionally design icons supplied by `icons8 <https://icons8.com>`_ which
provides established open-source projects with a free license.

I did need some icons that were too esoteric/project-specific for a design
house, so there are several I created myself. You'll note those in the source
because they don't start with ``icons8-`` in the ``sawx/icons`` directory.


Disclaimer
==========

Sawx, the Simple Application-framework for wxPython
Copyright (c) 2014-2019 Rob McMullen (feedback@playermissile.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
